===================
rpgmaker_mv_decoder
===================


.. image:: https://img.shields.io/pypi/v/rpgmaker_mv_decoder
        :target: https://pypi.python.org/pypi/rpgmaker_mv_decoder

.. image:: https://img.shields.io/github/workflow/status/kins-dev/rpgmaker_mv_decoder/Python%20application
        :target: https://github.com/kins-dev/rpgmaker_mv_decoder/actions/workflows/python-app.yml
        :alt: GitHub Workflow Status

.. image:: https://readthedocs.org/projects/rpgmaker-mv-decoder/badge/?version=latest
        :target: https://rpgmaker-mv-decoder.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Quickly decode assets for RPG Maker MV, even if you don't have the key


* Free software: MIT license
* Documentation: https://rpgmaker-mv-decoder.readthedocs.io.


Features
--------

* Figures out the encoding key automatically if multiple png files can be found
* Confidence level on the key found
* Allows overriding the key on the command line
* Fast
* Small code base
* Shows the top 10 keys found

Credits
-------

This package was created with Cookiecutter_ and
the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
